@@ -2,12 +2,14 @@
 # -*- encoding: utf-8 -*-
 
 from sys import path
-from os.path import dirname, join
+from os.path import dirname, join, abspath
 
-path.append(dirname(__file__))
+SCRIPT_DIR = dirname(abspath(__file__))
+path.append(dirname(SCRIPT_DIR))
 
 import logging
-from utils import BASE_DIR
+from delugeClient.utils import BASE_DIR
+from delugeClient.deluge import Deluge
 
 def addHandler(handler):
   handler.setFormatter(formatter)
